************************************
Specific Projections
************************************

ANNarchy provides a set of predefined ``Projection`` objects to ease the definition of standard networks.


Class CurrentInjection
=======================

.. autoclass:: ANNarchy.CurrentInjection
   :members:
